/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * Text describing the policy's purpose
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#description Policy#description}
    */
    readonly description?: string;
    /**
    * The enforcement configuration of the policy. For Sentinel, valid values are `hard-mandatory`, `soft-mandatory` and `advisory`. For OPA, Valid values are ``mandatory` and `advisory``
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#enforce_mode Policy#enforce_mode}
    */
    readonly enforceMode?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#id Policy#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The policy-as-code framework for the policy. Valid values are sentinel and opa
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#kind Policy#kind}
    */
    readonly kind?: string;
    /**
    * The name of the policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#name Policy#name}
    */
    readonly name: string;
    /**
    * Name of the organization that this policy belongs to
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#organization Policy#organization}
    */
    readonly organization?: string;
    /**
    * Text of a valid Sentinel or OPA policy
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#policy Policy#policy}
    */
    readonly policy: string;
    /**
    * The OPA query to run. Required for OPA policies
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#query Policy#query}
    */
    readonly query?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy tfe_policy}
*/
export declare class Policy extends cdktf.TerraformResource {
    static readonly tfResourceType = "tfe_policy";
    /**
    * Generates CDKTF code for importing a Policy resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the Policy to import
    * @param importFromId The id of the existing Policy that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the Policy to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/tfe/0.50.0/docs/resources/policy tfe_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PolicyConfig
    */
    constructor(scope: Construct, id: string, config: PolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _enforceMode?;
    get enforceMode(): string;
    set enforceMode(value: string);
    resetEnforceMode(): void;
    get enforceModeInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _kind?;
    get kind(): string;
    set kind(value: string);
    resetKind(): void;
    get kindInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _organization?;
    get organization(): string;
    set organization(value: string);
    resetOrganization(): void;
    get organizationInput(): string | undefined;
    private _policy?;
    get policy(): string;
    set policy(value: string);
    get policyInput(): string | undefined;
    private _query?;
    get query(): string;
    set query(value: string);
    resetQuery(): void;
    get queryInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
